@@ -43,15 +43,15 @@ test_that("test get_station_month_data", {
   expect_equal(
     unname(unlist(subset(df_min_2016_april,
                          date == as.Date("2016-04-15"))$value)),
-    c(NA, 16, 0, 7, 23, 27, 0, NA, 0, 17, 0, 1, 41, NA, 0, 25, NA,
-      24, 0, 0, NA, 20, 11, 16, 0, NA, NA, 33, NA, 0, 0, 28, NA, 0,
-      36, 25, 0, 0, 27, NA, 37))
+    c(NA, 16, 0, 7, 23, 27, 0, NA, 0, 17, 0, 1, 41, NA, NA, 0, 25,
+      NA, 24, 0, 0, NA, 20, 11, 16, 0, NA, NA, NA, 33, NA, 0, 0, 28,
+      NA, 0, 36, 25, 0, 0, 27, NA, 37))
   expect_equal(
     unname(unlist(subset(df_max_2016_march,
                          date == as.Date("2016-03-23"))$value)),
     c(60, NA, 50, 36, NA, 59, 59, 61, NA, 34, 51, 66, 43, 43, 55,
-      75, 57, NA, 61, NA, NA, NA, 57, 53, 51, 59, NA, NA, 73, NA, NA,
-      0, NA, 50, NA, 0, 46, 54, 0, 63, 54, 64, 48))
+      NA, 75, 57, NA, 61, NA, NA, NA, 57, 53, 51, 59, NA, NA, NA, 73,
+      NA, NA, 0, NA, 50, NA, 0, 46, 54, 0, 63, 54, 64, 48))
 
   # Expect warning from deprecated function
   expect_warning(get_station_single_month("RH", 2005, 1),
